@@ -11,9 +11,10 @@
 #![doc(
     html_favicon_url = "https://raw.githubusercontent.com/bytecodealliance/cap-std/main/media/cap-std.ico"
 )]
+#![cfg_attr(io_lifetimes_use_std, feature(io_safety))]
 
 #[cfg(not(windows))]
-mod posish;
+mod rsix;
 #[cfg(windows)]
 mod windows;
 
